@@ -116,7 +116,7 @@ class Sizes(object):
         if name.startswith('from_'):
             return lambda x: x * getattr(Sizes, name[5:])
         elif name.startswith('to_'):
-            return lambda x: x / getattr(Sizes, name[3:])
+            return lambda x: x // getattr(Sizes, name[3:])
         else:
             raise AttributeError
 
@@ -124,7 +124,7 @@ class Sizes(object):
         return count * getattr(Sizes, name)
 
     def _to(self, name, count):
-        return count / getattr(Sizes, name)
+        return count // getattr(Sizes, name)
 
 def imap_regexp(re_compiled, l, whole=False):
     """
